#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the DogsVsCats dataset."""

from tensorbay.opendataset.DogsVsCats.loader import DogsVsCats

__all__ = ["DogsVsCats"]
